@@ -277,6 +277,14 @@ class VariableOsInstallKernelBfqSet(ReadonlyVariable):
         return "off"
 
 
+class VariableOsInstallNomodeset(Variable):
+    type = "bool"
+    def get(self):
+        cmdLine = '/proc/cmdline'
+        if 'nomodeset' in readFile(cmdLine):
+            return "on"
+        return "off"
+
 class VariableOsInstallKernelAttr(Variable):
     """
     Install kernel attributes
@@ -285,6 +293,8 @@ class VariableOsInstallKernelAttr(Variable):
     def get(self):
         def generate():
             # 5 sec for usb hdd boot
+            if self.GetBool('os_install_nomodeset'):
+                yield "nomodeset"
             if self.Get('os_install_root_type') == 'usb-hdd':
                 yield "scandelay=5"
             if (self.GetBool('os_install_mdadm_set') or
